M = Manifold(2, 'M')
X = M.chart('x y'); x, y = X[:]
v = M.vector_field(-y, x, name='v')
g = v.plot(scale=0.5, color='green', linestyle='--', width=1, arrowsize=6)
sphinx_plot(g)